#######################
PyDMWaveformTable
#######################

.. autoclass:: pydm.widgets.waveformtable.PyDMWaveformTable
   :members:
   :show-inheritance:


.. note::
   See `QTableWidget Documentation <https://doc.qt.io/qtforpython-5/PySide2/QtWidgets/QTableWidget.html>`_ for all inherited properties and methods.